@@ -1,7 +1,7 @@
 use std::path::PathBuf;
 use structopt::StructOpt;
 
-#[derive(Debug, StructOpt)]
+#[derive(Debug, Clone, StructOpt)]
 #[structopt(name = "tidyVCF", about = "generates tidy tables from VCF files")]
 pub struct Opt {
     /// Input file, stdin if not present
@@ -16,7 +16,15 @@ pub struct Opt {
     #[structopt(short, long)]
     pub stack: bool,
 
-    /// Delimiting character to join sample names to fmt fields
-    #[structopt(short = "j")]
-    pub inner_delim: Option<String>,
+    /// comma separated output (default is tab)
+    #[structopt(short, long)]
+    pub csv: bool,
+
+    /// Delimiting character to join sample names to fmt fields (default is "_")
+    #[structopt(short = "j", long = "sample-delim")]
+    pub sample_delim: Option<String>,
+
+    /// Prefix string for INFO fields to avoid name collisions (default is "info_")
+    #[structopt(short = "p", long)]
+    pub info_prefix: Option<String>,
 }
